@@ -11,13 +11,14 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from dataclasses import dataclass, field
+from dataclasses import field
 from datetime import datetime
 from typing import Optional
 
 from dataclasses_json import LetterCase, config, dataclass_json
 from dateutil import parser
 from marshmallow import fields
+from pydantic.dataclasses import dataclass
 
 from centraldogma.data.creator import Creator
 
